@@ -7,7 +7,7 @@ import argparse
 import os
 import subprocess
 import urllib.request, urllib.error, urllib.parse
-from lib import utils
+from . import utils
 import sys
 from shutil import copyfile
 from .agent import run_agent
@@ -25,6 +25,7 @@ def main():
     action = results.action
     argument = results.argument
     second_argument = results.second_argument
+    third_argument  = results.third_argument
     cloud_provider = results.cloud_provider
     args = vars(results)
     verbose = False
@@ -68,7 +69,7 @@ def main():
             try_num += 1
             print ("Initializing agent")
             install_succeed = handle_cloud_provider(cloud_provider, instance_details_path) and install_and_init_agent(
-                argument, second_argument, modules_path)
+                argument, second_argument, third_argument, modules_path)
 
         if not install_succeed:
             print("init failed")
@@ -79,7 +80,7 @@ def main():
         print ("Unrecognized action. Please use one of the following : add-worker, add-collector, configure")
 
 
-def install_and_init_agent(token, account_id, modules_path):
+def install_and_init_agent(token, account_id, custom_host, modules_path):
     # Paths
     runscript = None
     try:
@@ -90,6 +91,7 @@ def install_and_init_agent(token, account_id, modules_path):
         handle_base_modules(dirname, modules_path)
         handle_yml_file(dirname)
         handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
+        handle_custom_host(custom_host)
         handle_agent_path(spotinst_agent_path)
         runscript = subprocess.Popen(script_full_path)
         runscript.wait()
@@ -167,6 +169,9 @@ def handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
     os.putenv("SPOTINST_AGENT_PATH", spotinst_agent_path)
     os.chmod(script_full_path, 0o777)
 
+def handle_custom_host(custom_host):
+    if custom_host is not None:
+        os.putenv("CUSTOM_HOST", custom_host)
 
 def write_creds_path(account_id, creds_file, token):
     if account_id is not None:
@@ -201,6 +206,10 @@ def parse_arguments():
                         help='The name of worker or collector to add or configure.',
                         nargs='?')
     parser.add_argument('second_argument',
+                        action="store",
+                        help='Additional argument.',
+                        nargs='?'),
+    parser.add_argument('third_argument',
                         action="store",
                         help='Additional argument.',
                         nargs='?')
