@@ -155,7 +155,7 @@ class TaskManager(object):
                     # Only attempt to load classes that are infact classes but not the base Module class
                     self.log.info("Checking " + str(modname) + " Attribute " + str(attrname))
 
-                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module:
+                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module and attr != system.Module:
                         # Get class name
                         fqcn = '.'.join([modname, attrname])
                         self.log.info("Module loaded : " + fqcn)
